@@ -20,8 +20,6 @@
 #include <QSpinBox>
 #include <QtDebug>
 
-using namespace Utils;
-
 namespace CppEditor::Internal {
 
 class LineCountSpinBox : public QWidget
@@ -56,7 +54,7 @@ LineCountSpinBox::LineCountSpinBox(QWidget *parent)
     m_unitLabel = new QLabel(Tr::tr("lines"));
 
     using namespace Layouting;
-    Row { m_checkBox, m_opLabel, m_spinBox, m_unitLabel, }.attachTo(this, WithoutMargins);
+    Row { m_checkBox, m_opLabel, m_spinBox, m_unitLabel, noMargin }.attachTo(this);
 
     auto handleChange = [this] {
         updateFields();
@@ -88,9 +86,8 @@ void LineCountSpinBox::updateFields()
     m_unitLabel->setEnabled(enabled);
 }
 
-CppQuickFixSettingsWidget::CppQuickFixSettingsWidget(QWidget *parent)
-    : QWidget(parent)
-    , m_typeSplitter("\\s*,\\s*")
+CppQuickFixSettingsWidget::CppQuickFixSettingsWidget()
+    : m_typeSplitter("\\s*,\\s*")
 {
     m_lines_getterOutsideClass = new LineCountSpinBox;
     m_lines_getterInCppFile = new LineCountSpinBox;
@@ -223,7 +220,8 @@ e.g. name = "m_test_foo_":
         Tr::tr("Inside class:"), Tr::tr("Default"), Tr::tr("Default"), br,
         Tr::tr("Outside class:"), m_lines_setterOutsideClass, m_lines_getterOutsideClass, br,
         Tr::tr("In .cpp file:"), m_lines_setterInCppFile, m_lines_getterInCppFile, br,
-    }.attachTo(functionLocationsGrid, WithoutMargins);
+        noMargin,
+    }.attachTo(functionLocationsGrid);
 
     if (QGridLayout *gl = qobject_cast<QGridLayout*>(functionLocationsGrid->layout()))
         gl->setHorizontalSpacing(48);
@@ -319,6 +317,8 @@ e.g. name = "m_test_foo_":
     connect(m_radioButton_addUsingnamespace, &QRadioButton::clicked, then);
     connect(m_radioButton_generateMissingNamespace, &QRadioButton::clicked, then);
     connect(m_radioButton_rewriteTypes, &QRadioButton::clicked, then);
+
+    loadSettings(CppQuickFixSettings::instance());
 }
 
 void CppQuickFixSettingsWidget::loadSettings(CppQuickFixSettings *settings)
@@ -426,6 +426,13 @@ void CppQuickFixSettingsWidget::saveSettings(CppQuickFixSettings *settings)
     }
 }
 
+void CppQuickFixSettingsWidget::apply()
+{
+    const auto s = CppQuickFixSettings::instance();
+    saveSettings(s);
+    s->saveAsGlobalSettings();
+}
+
 void CppQuickFixSettingsWidget::currentCustomItemChanged(QListWidgetItem *newItem,
                                                          QListWidgetItem *oldItem)
 {
