@@ -1,50 +1,30 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "iosdsymbuildstep.h"
 
 #include "iosconstants.h"
 #include "iosconfigurations.h"
 #include "iosrunconfiguration.h"
+#include "iostr.h"
 
 #include <extensionsystem/pluginmanager.h>
-#include <projectexplorer/target.h>
-#include <projectexplorer/project.h>
+
+#include <projectexplorer/buildconfiguration.h>
 #include <projectexplorer/buildsteplist.h>
 #include <projectexplorer/kitinformation.h>
 #include <projectexplorer/processparameters.h>
+#include <projectexplorer/project.h>
 #include <projectexplorer/projectexplorer.h>
-#include <projectexplorer/buildconfiguration.h>
 #include <projectexplorer/projectexplorerconstants.h>
+#include <projectexplorer/target.h>
 
 #include <qtsupport/qtkitinformation.h>
 #include <qtsupport/qtparser.h>
 
-#include <utils/stringutils.h>
+#include <utils/process.h>
 #include <utils/qtcassert.h>
-#include <utils/qtcprocess.h>
+#include <utils/stringutils.h>
 
 #include <QGridLayout>
 #include <QLabel>
@@ -56,13 +36,39 @@ using namespace Core;
 using namespace ProjectExplorer;
 using namespace Utils;
 
-namespace Ios {
-namespace Internal {
+namespace Ios::Internal {
 
-static const char USE_DEFAULT_ARGS_PARTIAL_KEY[] = ".ArgumentsUseDefault";
-static const char COMMAND_PARTIAL_KEY[] = ".Command";
-static const char ARGUMENTS_PARTIAL_KEY[] = ".Arguments";
-static const char CLEAN_PARTIAL_KEY[] = ".Clean";
+const char USE_DEFAULT_ARGS_PARTIAL_KEY[] = ".ArgumentsUseDefault";
+const char COMMAND_PARTIAL_KEY[] = ".Command";
+const char ARGUMENTS_PARTIAL_KEY[] = ".Arguments";
+const char CLEAN_PARTIAL_KEY[] = ".Clean";
+
+class IosDsymBuildStep : public AbstractProcessStep
+{
+public:
+    IosDsymBuildStep(BuildStepList *parent, Id id);
+
+    QWidget *createConfigWidget() override;
+    void setArguments(const QStringList &args);
+    QStringList arguments() const;
+    QStringList defaultArguments() const;
+    FilePath defaultCommand() const;
+    FilePath command() const;
+    void setCommand(const FilePath &command);
+    bool isDefault() const;
+
+private:
+    void setupOutputFormatter(OutputFormatter *formatter) override;
+    QVariantMap toMap() const override;
+    bool fromMap(const QVariantMap &map) override;
+
+    QStringList defaultCleanCmdList() const;
+    QStringList defaultCmdList() const;
+
+    QStringList m_arguments;
+    FilePath m_command;
+    bool m_clean;
+};
 
 IosDsymBuildStep::IosDsymBuildStep(BuildStepList *parent, Id id) :
     AbstractProcessStep(parent, id),
@@ -86,7 +92,7 @@ QVariantMap IosDsymBuildStep::toMap() const
     map.insert(id().withSuffix(USE_DEFAULT_ARGS_PARTIAL_KEY).toString(),
                isDefault());
     map.insert(id().withSuffix(CLEAN_PARTIAL_KEY).toString(), m_clean);
-    map.insert(id().withSuffix(COMMAND_PARTIAL_KEY).toString(), command().toVariant());
+    map.insert(id().withSuffix(COMMAND_PARTIAL_KEY).toString(), command().toSettings());
     return map;
 }
 
@@ -97,7 +103,7 @@ bool IosDsymBuildStep::fromMap(const QVariantMap &map)
     bool useDefaultArguments = map.value(
                 id().withSuffix(USE_DEFAULT_ARGS_PARTIAL_KEY).toString()).toBool();
     m_clean = map.value(id().withSuffix(CLEAN_PARTIAL_KEY).toString(), m_clean).toBool();
-    m_command = FilePath::fromVariant(map.value(id().withSuffix(COMMAND_PARTIAL_KEY).toString()));
+    m_command = FilePath::fromSettings(map.value(id().withSuffix(COMMAND_PARTIAL_KEY).toString()));
     if (useDefaultArguments) {
         m_command = defaultCommand();
         m_arguments = defaultArguments();
@@ -202,12 +208,11 @@ QStringList IosDsymBuildStep::arguments() const
     return m_arguments;
 }
 
-
 QWidget *IosDsymBuildStep::createConfigWidget()
 {
     auto widget = new QWidget;
 
-    auto commandLabel = new QLabel(tr("Command:"), widget);
+    auto commandLabel = new QLabel(Tr::tr("Command:"), widget);
 
     auto commandLineEdit = new QLineEdit(widget);
     commandLineEdit->setText(command().toString());
@@ -215,9 +220,9 @@ QWidget *IosDsymBuildStep::createConfigWidget()
     auto argumentsTextEdit = new QPlainTextEdit(widget);
     argumentsTextEdit->setPlainText(Utils::ProcessArgs::joinArgs(arguments()));
 
-    auto argumentsLabel = new QLabel(tr("Arguments:"), widget);
+    auto argumentsLabel = new QLabel(Tr::tr("Arguments:"), widget);
 
-    auto resetDefaultsButton = new QPushButton(tr("Reset to Default"), widget);
+    auto resetDefaultsButton = new QPushButton(Tr::tr("Reset to Default"), widget);
     resetDefaultsButton->setLayoutDirection(Qt::RightToLeft);
     resetDefaultsButton->setEnabled(!isDefault());
 
@@ -238,7 +243,8 @@ QWidget *IosDsymBuildStep::createConfigWidget()
 
     connect(argumentsTextEdit, &QPlainTextEdit::textChanged, this,
             [this, argumentsTextEdit, resetDefaultsButton, updateDetails] {
-        setArguments(Utils::ProcessArgs::splitArgs(argumentsTextEdit->toPlainText()));
+        setArguments(ProcessArgs::splitArgs(argumentsTextEdit->toPlainText(),
+                                            HostOsInfo::hostOs()));
         resetDefaultsButton->setEnabled(!isDefault());
         updateDetails();
     });
@@ -270,9 +276,7 @@ QWidget *IosDsymBuildStep::createConfigWidget()
     return widget;
 }
 
-//
 // IosDsymBuildStepFactory
-//
 
 IosDsymBuildStepFactory::IosDsymBuildStepFactory()
 {
@@ -282,5 +286,4 @@ IosDsymBuildStepFactory::IosDsymBuildStepFactory()
     setDisplayName("dsymutil");
 }
 
-} // namespace Internal
-} // namespace Ios
+} // Ios::Internal
